@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yaml
 version: 0.8.16
-id: yaml-0.8.16-dde1f04caad6e58716b323c82d57d5b4
-key: yaml_KljSP4k21h80PhjuA45xgb
+id: yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
+key: yaml_Gt3Jc9yFHAOFX97IB3ZFyz
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: stable
@@ -23,10 +23,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.16
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.16
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yaml-0.8.16
-hs-libraries: HSyaml-0.8.16-KljSP4k21h80PhjuA45xgb
+hs-libraries: HSyaml-0.8.16-Gt3Jc9yFHAOFX97IB3ZFyz
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
-    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
@@ -35,11 +35,11 @@ depends:
     enclosed-exceptions-1.0.1.1-609f4f396c20c8289c1e73bde62fbdf4
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
 haddock-html: /usr/share/doc/haskell-yaml/html
